##  Running Manual Synchronization
Synchronization occurs automatically every 30 minutes. During each run, the system checks for changes in SAP Cloud ALM projects and updates the corresponding SAP LeanIX fact sheets.
You can also manually execute a synchronization run by clicking the refresh icon in the top right corner of the Agile Tracking tab of the fact sheet. When there are child fact sheets linked to SAP Cloud ALM projects, the data for all of them is synchronized in the same run.
